pub enum ChromeAction {
None,
Repaint,
SetJsPolicy(JsPolicy),
Navigate(Url),
Back,
Reload,
EnableIme,
DevToolsRequest {
id: u64,
method: String,
params: String,
},
}Expand description
An action the chrome wants the browser core to perform on the active tab or window.
Variants
None
Nothing to do.
Repaint
The chrome changed visually; repaint the window.
SetJsPolicy(JsPolicy)
Set the JS policy.
Navigate the active tab to this URL (e.g. Enter in the address bar).
Back
Go back in the active tab’s history.
Reload
Reload the active tab.
EnableIme
The chrome acquired a text field and wants OS-level IME enabled.
DevToolsRequest
A page asked the DevTools bridge to inspect rendered state.