BasicChrome

Struct BasicChrome 

pub struct BasicChrome { /* private fields */ }
The default chrome for a browser window: a top toolbar and the page content area below it.

Implementations

Source

impl BasicChrome

pub fn new() -> Self

Create a new default chrome with an empty toolbar.